@@ -34,6 +34,7 @@ proc xcircuit::getsubckttext {name} {
 	 }
       }
    }
+   deselect selected
    return ""
 }
 
@@ -59,6 +60,14 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
 
    set techname [.dialog.techself.techselect cget -text]
    set symbolname [.dialog.textent.txt get]
+   if {[string length $symbolname] == 0} {
+      set symbolname [page label]
+      if {[string length $symbolname] == 0 || [string first "Page " $symbolname] >= 0} {
+         puts stderr "Symbol/Schematic has no name!"
+         consoleup
+         return
+      }
+   }
 
    if {[string first :: $symbolname] >= 0} {	;# symbolname has tech name embedded
       set techname ""
@@ -72,6 +81,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    # Therefore, create an object but don't use xcircuit::symbol
 
    if {$filename == ""} {
+      deselect selected
       xcircuit::symbol make ${techname}${symbolname} $XCOps(library);
       set schematicname [schematic get]
       set noschem 0
@@ -483,6 +493,8 @@ proc xcircuit::addpinarranger {w {pinlist {}}} {
    # If so, we pass the ordered list to the symbol construction routine, and
    # we also prevent symbol pins from being deleted.  
 
+   config suspend true	;# suspend graphics and change count
+
    if {$pinlist == {}} {
       set pinlist [xcircuit::getpinlist [page label]]
       if {[xcircuit::getsubckttext [page label]] != {}} {
@@ -535,6 +547,7 @@ proc xcircuit::addpinarranger {w {pinlist {}}} {
       button ${w}.bbar.movebottom -text "Move Bottom" -bg beige -command \
 	{xcircuit::movepinbottom}
    }
+   config suspend false
 
    if {$orderedpins == 0} {
       pack ${w}.bbar.remove -side left -ipadx 10
@@ -585,6 +598,8 @@ proc xcircuit::promptmakesymbol {{name ""}} {
           wm withdraw .dialog}
   .dialog.textent.title.field configure -text "Confirm symbol name:"
   .dialog.textent.txt delete 0 end
+  if {[string length $name] == 0 && [string first "Page " [page label]] < 0} {
+      set name [page label]}
   .dialog.textent.txt insert 0 $name
 
   xcircuit::popupdialog
