@@ -42,7 +42,6 @@
 /*-------------------------------------------------------------------------*/
 
 extern Display	*dpy;   /* Works well to make this globally accessible */
-extern int *appcolors;
 extern Cursor	appcursors[NUM_CURSORS];
 extern Globaldata xobjs;
 extern XCWindowData *areawin;
@@ -50,6 +49,8 @@ extern char _STR[150];
 extern short fontcount;
 extern fontinfo *fonts;
 extern Boolean was_preselected;
+extern int number_colors;
+extern colorindex *colorlist;
 
 /*---------------------------------------------------------*/
 /* Find the Helvetica font for use in labeling the objects */
@@ -1263,7 +1264,7 @@ void tech_set_changes(TechPtr refns)
          if (getchanges(thisobj) > 0) {
             ns = GetObjectTechnology(thisobj);
 	    if ((refns == NULL) || (refns == ns)) 
-	       ns->flags |= LIBRARY_CHANGED;
+	       ns->flags |= TECH_CHANGED;
 	 }
       }
    }
@@ -1275,7 +1276,7 @@ void tech_set_changes(TechPtr refns)
 
 void tech_mark_changed(TechPtr ns)
 {
-   if (ns != NULL) ns->flags |= LIBRARY_CHANGED;
+   if (ns != NULL) ns->flags |= TECH_CHANGED;
 }
 
 /*------------------------------------------------------*/
@@ -1389,6 +1390,12 @@ void catmove(int x, int y)
 /*------------------------------------------------------*/
 /* Make a duplicate of an object, put in the User	*/
 /* Library or the current library (if we're in one).	*/
+/*							*/
+/* Updated 2/8/2014 for use with technology namespaces:	*/
+/* it is most likely that the copied object is to be	*/
+/* modified but kept in the same namespace.  So, when	*/
+/* renaming the object, prepend "_" to the object name	*/
+/* instead of the namespace prefix.			*/
 /*------------------------------------------------------*/
 
 void copycat()
@@ -1398,6 +1405,7 @@ void copycat()
    objinstptr libobj;
    oparamptr ops, newops;
    int i, libnum;
+   char *cptr;
 
    libnum = is_library(topobject);
    if (libnum < 0) libnum = USERLIB - LIBRARY;  /* default */
@@ -1419,7 +1427,13 @@ void copycat()
 
       /* give the new object a unique name */
 
-      sprintf((*newobj)->name, "_%s", oldobj->name);
+      cptr = strstr(oldobj->name, "::");
+      if (cptr == NULL)
+	 sprintf((*newobj)->name, "_%s", oldobj->name);
+      else {
+	 strcpy((*newobj)->name, oldobj->name);
+	 sprintf((*newobj)->name + (cptr - oldobj->name) + 2, "_%s", cptr + 2);
+      }
       checkname(*newobj);
 
       /* copy other object properties */
@@ -1696,7 +1710,6 @@ void catalog_op(int op, int x, int y)
 		  if (newselect == areawin->selectlist + areawin->selects) {
 		     newselect = allocselect();
 		     *newselect = newinst;
-		     XcSetFunction(GXcopy);
 		     XcTopSetForeground(SELECTCOLOR);
 		     UDrawObject(*libobj, SINGLE, SELECTCOLOR,
 				xobjs.pagelist[areawin->page]->wirewidth, NULL);
