@@ -61,8 +61,8 @@ menustruct FontStyles[] = {
 };
 
 menustruct FontEncodings[] = {
-	{"Standard", setaction(fontencoding, Number(0))},
-	{"ISO-Latin1", action(fontencoding, Number(2))},
+	{"Standard", action(fontencoding, Number(0))},
+	{"ISO-Latin1", setaction(fontencoding, Number(2))},
 };
 
 menustruct TextSpacing[] = {
@@ -295,7 +295,9 @@ menustruct FileMenu[] = {
 #endif
 	{"Read Xcircuit File", action(getfile, Number(NORMAL))},
 	{"Import Xcircuit PS", action(getfile, Number(IMPORT))},
+#if !defined(HAVE_CAIRO) || defined(HAVE_GS)
 	{"Import background PS", action(getfile, Number(PSBKGROUND))},
+#endif
 #ifdef HAVE_CAIRO
 	{"Import graphic image", action(getfile, Number(IMPORTGRAPHIC))},
 #endif
