@@ -887,6 +887,8 @@ void swapschem(int allow_create, int libnum, char *fullname)
 
 	 if (eventmode == MOVE_MODE || eventmode == COPY_MODE)
 	    standard_element_delete(ERASE);
+	 else
+	    unselect_all();
 
 	 /* Generate a library instance for this object and set the */
 	 /* top instance to point to it.			    */
@@ -952,6 +954,7 @@ void swapschem(int allow_create, int libnum, char *fullname)
 	       (*pinlab)->position.x = 0;
 	       (*pinlab)->position.y = topobject->parts * (TEXTHEIGHT + 10);
 	       (*pinlab)->passed = NULL;
+	       (*pinlab)->cycle = NULL;
 	       u2u_snap(&((*pinlab)->position));
 	       (*pinlab)->string = stringcopy(lpin->string);
 	       incr_changes(topobject);
